Struct MineralInjection

pub struct MineralInjection;
Struct implements the MineralInjectionTrait for executing the Balling mineral dosing. It also contains state attributes for the actuators. Thread communication is as follows:

graph LR mineral_injection[Mineral injection] --> relay_manager[Relay Manager] relay_manager --> mineral_injection signal_handler[Signal handler] --> mineral_injection

Implementations

Source

impl MineralInjection

pub fn new() -> MineralInjection

Provide a struct of type MineralInjection

fn send_and_confirm( &self, balling_channels: &mut BallingChannels, command: InternalCommand, action_description: &str, )

Sends a command to the relay manager and handles the response. Logs an error if either the send or receive operation fails.