pub struct MineralInjection;Expand description
Struct implements the MineralInjectionTrait for executing the Balling mineral dosing. It also contains state attributes for the actuators. Thread communication is as follows:
Implementations
Sourceimpl MineralInjection
impl MineralInjection
Sourcepub fn new() -> MineralInjection
pub fn new() -> MineralInjection
Provide a struct of type MineralInjection
Sourcefn send_and_confirm(
&self,
balling_channels: &mut BallingChannels,
command: InternalCommand,
action_description: &str,
)
fn send_and_confirm( &self, balling_channels: &mut BallingChannels, command: InternalCommand, action_description: &str, )
Sends a command to the relay manager and handles the response. Logs an error if either the send or receive operation fails.